/*
 * CDemo.c - Demonstrates the basic usage of PVW32.DLL.
 * ~~~~~~~   It simply loads and displays an image using a scrollable window.
 *
 * Author: Jan Patera, 1999-2009
 */

#include <windows.h>
#include "PVW32DLL.h"

#define XLine 10
#define YLine 10
#define XPage 100
#define YPage 100

char        szFrameClass [] = "PVW32Demo";
int         loaded=FALSE;
LPPVHandle  PVHandle;
PVImageInfo pvii;

/* This callback function displays the decompression progress
 */
BOOL WINAPI ProgressProcedure(int progress, void *hwnd)
{
  char s[64];

  wsprintf(s, "PictView32 DLL Basic Demo (%i%%)", progress);
  SetWindowText((HWND)hwnd, s);
  return FALSE;
}

void ScrollTo(HWND hwnd, int x, int y)
{
  int maxx, maxy, tmp;
  
  GetScrollRange(hwnd, SB_HORZ, &tmp, &maxx);
  GetScrollRange(hwnd, SB_VERT, &tmp, &maxy);
  x=min(x, maxx);
  y=min(y, maxy);
  if (x != -1)
   SetScrollPos(hwnd, SB_HORZ, x, TRUE);
  if (y != -1)
   SetScrollPos(hwnd, SB_VERT, y, TRUE);
}


void VScroll(HWND hwnd, int ScrollRequest, int ThumbPos)
{
  int YPos=GetScrollPos(hwnd, SB_VERT);
  
  switch (ScrollRequest)
   {
     case SB_LINEDOWN: ScrollTo(hwnd, -1, YPos+YLine); break;
     case SB_LINEUP: ScrollTo(hwnd, -1, YPos-YLine); break;
     case SB_PAGEDOWN: ScrollTo(hwnd, -1, YPos+YPage); break;
     case SB_PAGEUP: ScrollTo(hwnd, -1, YPos-YPage); break;
     case SB_THUMBPOSITION: ScrollTo(hwnd, -1, ThumbPos); break;
     case SB_THUMBTRACK: ScrollTo(hwnd, -1, ThumbPos); break;
  }
  InvalidateRect(hwnd, NULL, FALSE);
}

void HScroll(HWND hwnd, int ScrollRequest, int ThumbPos)
{
  int XPos=GetScrollPos(hwnd, SB_HORZ);

  switch (ScrollRequest)
   {
     case SB_LINERIGHT: ScrollTo(hwnd, XPos+XLine, -1); break;
     case SB_LINELEFT: ScrollTo(hwnd, XPos-XLine, -1); break;
     case SB_PAGERIGHT: ScrollTo(hwnd, XPos+XPage, -1); break;
     case SB_PAGELEFT: ScrollTo(hwnd, XPos-XPage, -1); break;
     case SB_THUMBPOSITION: ScrollTo(hwnd, ThumbPos, -1); break;
     case SB_THUMBTRACK: ScrollTo(hwnd, ThumbPos, -1); break;
  }
  InvalidateRect(hwnd, NULL, FALSE);
}

/* The main window procedure
 */
LRESULT CALLBACK FrameWndProc(HWND hwnd, UINT message, WPARAM wParam,
     LPARAM lParam)
{
  PAINTSTRUCT  ps;
  HDC          hdc;
  unsigned     cw, ch, sw, sh, XRange, YRange;
  RECT         rect;

  switch (message)
  {
    case WM_PAINT:
            hdc = BeginPaint(hwnd, &ps);
            if (!loaded)
             {
               PVCODE   code;
               RECT     rect;

               loaded = TRUE;
               rect.top = rect.left = 0; // paint to top-left corner
               rect.right = ps.rcPaint.right; // do not paint more than necessary
               rect.bottom = ps.rcPaint.bottom;
               code = PVReadImage2(PVHandle, hdc, &rect, ProgressProcedure, hwnd, 0);
               if (code != PVC_OK)
                {
                  MessageBox(hwnd, PVGetErrorText(code), "Error calling PVW32.DLL", MB_ICONEXCLAMATION);
                  if (code != PVC_CANCELED)
                    PostMessage(hwnd, WM_CLOSE, 0, 0);
                }
             }
            else
             {
               SetViewportOrgEx(hdc, -GetScrollPos(hwnd, SB_HORZ),
                -GetScrollPos(hwnd, SB_VERT), NULL);
               PVDrawImage(PVHandle, hdc, 0, 0, NULL);
             }
            EndPaint(hwnd, &ps);
            return 0;
    case WM_SIZE:
            GetWindowRect(hwnd, &rect);
            cw = rect.right-rect.left-2*GetSystemMetrics(SM_CXFRAME);
            ch = rect.bottom-rect.top-2*GetSystemMetrics(SM_CYFRAME)-GetSystemMetrics(SM_CYCAPTION);
            sw = GetSystemMetrics(SM_CXVSCROLL); sh = GetSystemMetrics(SM_CYHSCROLL);
            XRange = YRange = 0;
            if (pvii.Width+sw <= cw)  /* no horizontal scrollbar */
             {
               if (pvii.Height > ch)
                YRange=pvii.Height-ch;
             }
            else
             if (pvii.Width > cw)     /* yes horizontal scrollbar */
              {
                if (pvii.Height > ch-sh)
                 YRange=pvii.Height-ch+sh;
                else
                 sw=0;
                XRange=pvii.Width-cw+sw;
              }
             else                     /* maybe horizontal scrollbar */
              if (pvii.Height > ch)   /* yes vertical and therefore yes horizontal */
               {
                 XRange=pvii.Width-cw+sw;
                 YRange=pvii.Height-ch+sh;
               }
            SetScrollRange(hwnd, SB_HORZ, 0, XRange, TRUE/*redraw*/);
            SetScrollRange(hwnd, SB_VERT, 0, YRange, TRUE/*redraw*/);
            ShowScrollBar(hwnd, SB_HORZ, XRange ? TRUE : FALSE);
            ShowScrollBar(hwnd, SB_VERT, YRange ? TRUE : FALSE);
            break;
    case WM_VSCROLL:
            VScroll(hwnd, LOWORD(wParam), HIWORD(wParam));
            break;
    case WM_HSCROLL:
            HScroll(hwnd, LOWORD(wParam), HIWORD(wParam));
            break;

    case WM_QUERYENDSESSION:
    case WM_CLOSE:
            break;

    case WM_DESTROY:
            PostQuitMessage (0);
            return 0;
  }

  return DefWindowProc(hwnd, message, wParam, lParam);
}

int PASCAL WinMain (HINSTANCE hInstance, HINSTANCE hPrevInstance,
                    LPSTR lpszCmdLine, int nCmdShow)
{
  MSG      msg;
  WNDCLASS wndclass;
  PVCODE   code;
  HWND     hWnd;

  wndclass.style         = 0;
  wndclass.lpfnWndProc   = FrameWndProc;
  wndclass.cbClsExtra    = 0;
  wndclass.cbWndExtra    = 0;
  wndclass.hInstance     = hInstance;
  wndclass.hIcon         = 0;
  wndclass.hCursor       = LoadCursor (NULL, IDC_ARROW);
  wndclass.hbrBackground = (HBRUSH)GetStockObject (WHITE_BRUSH);
  wndclass.lpszMenuName  = NULL;
  wndclass.lpszClassName = szFrameClass;

  RegisterClass (&wndclass) ;

  if (!lpszCmdLine || !*lpszCmdLine)
    return MessageBox(0, "Usage: CDemo.exe image_file", "PictView32 DLL Basic Demo", 0);

  pvii.Width=pvii.Height=CW_USEDEFAULT;

  /* Here it can be checked which version of the DLL is loaded */
  code=PVGetDLLVersion();
  code=PVOpenImage(&PVHandle, lpszCmdLine, &pvii, sizeof(pvii));
  if (PVC_OK != code)
   {
     MessageBox(0, PVGetErrorText(code), "Error calling PVW32.DLL", MB_ICONEXCLAMATION);
     return 0;
   }

  PVSetBkHandle(PVHandle, (HBRUSH)(COLOR_WINDOW+1));
  hWnd = CreateWindow(szFrameClass, "PictView32 DLL Basic Demo",
    WS_OVERLAPPEDWINDOW | WS_VSCROLL | WS_HSCROLL,
    CW_USEDEFAULT, CW_USEDEFAULT,
    pvii.Width + 2*GetSystemMetrics(SM_CXFRAME),
    pvii.Height + 2*GetSystemMetrics(SM_CYFRAME) + GetSystemMetrics(SM_CYCAPTION),
    NULL, NULL, hInstance, NULL);

  ShowWindow(hWnd, SW_SHOWNORMAL);
  ShowScrollBar(hWnd, SB_BOTH, FALSE);
  UpdateWindow(hWnd);

  while (GetMessage(&msg, NULL, 0, 0))
  {
    TranslateMessage(&msg);
    DispatchMessage(&msg);
  }
  PVCloseImage(PVHandle);
  return msg.wParam;
}

