/*
 * Convert.c - Demonstrates basic usage of PVW32Cnv.DLL.
 * ~~~~~~~~~   Displays a dialog window giving full control over image conversion.
 *
 * NOTE: must be linked with Convert.rc and PVW32Cnv.lib
 *
 * Author: Jan Patera, 2001-2004
 */

#include <windows.h>
#include <windowsx.h>
#include "Convert.rh"


BOOL CALLBACK SaveDlgProc(HWND HWindow, UINT uMsg, WPARAM wParam, LPARAM lParam)
{
  switch (uMsg)
  {
    case WM_INITDIALOG:
    {
      /* If there was a file name on the command-line, display it */
      if (lParam && *(char*)lParam) {
        Edit_SetText(GetDlgItem(HWindow, IDC_INPUT), (char*)lParam);
      }
      /* Set some defaults */
      Button_SetCheck(GetDlgItem(HWindow, IDC_BMP), TRUE);
      Button_SetCheck(GetDlgItem(HWindow, IDC_NO_COMPRESSION), TRUE);
      Button_SetCheck(GetDlgItem(HWindow, IDC_COLOR_DEFAULT), TRUE);
      Button_SetCheck(GetDlgItem(HWindow, IDC_ROT0), TRUE);
      CheckDlgButton(HWindow, IDC_STRIPS, BST_CHECKED);
      return TRUE;
    }

    case WM_COMMAND:
    {
      switch (LOWORD(wParam))
      {
        case IDOK:
        {
          int fmts[] = {PVF_BMP, PVF_CEL, PVF_CUT, PVF_GIF, PVF_ICO, PVF_IRF, PVF_JPG, PVF_LBM, PVF_PIC, PVF_PCX, PVF_PNG, PVF_PNM, PVF_RAS, PVF_RAW, PVF_RIX, PVF_RLE, PVF_SGI, PVF_TGA, PVF_TIFF, PVF_WBMP};
          int comprs[] = {PVCS_DEFAULT, PVCS_NO_COMPRESSION, PVCS_RLE, PVCS_PACKBITS, PVCS_LZW, PVCS_HUFFMAN, PVCS_CCITT_3, PVCS_CCITT_4, PVCS_JPEG_HUFFMAN, PVCS_DEFLATE};
          int clrs[] = {IDC_MONO, IDC_16, IDC_256, IDC_GRAYS, IDC_HC15, IDC_TC24, IDC_TC32, IDC_UNIFORM};
          int colors[] = {2, 16, 256, 256, PV_COLOR_HC15, PV_COLOR_TC24, PV_COLOR_TC32, 256};
          int outFmt = 0, outCompr = 0, a, outColors = 0/*default*/;
          PVSaveImageInfo sii;
          PVImageInfo     ii;
          PVCODE          code;
          char            inputFName[MAX_PATH];
          char            outputFName[MAX_PATH];
          LPPVHandle      PVHandle;

          /* Determine chosen file format */
          for (a = 0; a < sizeof(fmts)/sizeof(fmts[0]); a++) {
            if (Button_GetCheck(GetDlgItem(HWindow, fmts[a]+100))) {
              outFmt = fmts[a];
            }
          }
          /* Determine chosen compression scheme */
          for (a = 0; a < sizeof(comprs)/sizeof(comprs[0]); a++) {
            if (Button_GetCheck(GetDlgItem(HWindow, comprs[a]+100))) {
              outCompr = comprs[a];
            }
          }
          /* Determine chosen bit-depth */
          for (a = 0; a < sizeof(clrs)/sizeof(clrs[0]); a++) {
            if (Button_GetCheck(GetDlgItem(HWindow, clrs[a]))) {
              outColors = colors[a];
            }
          }

          /* Determine input and output files */
          Edit_GetText(GetDlgItem(HWindow, IDC_INPUT), inputFName, sizeof(inputFName));
          Edit_GetText(GetDlgItem(HWindow, IDC_OUTPUT), outputFName, sizeof(outputFName));

          /* Check whether the input file exists and PVW32Cnv.dll knows it */
          code = PVOpenImage(&PVHandle, inputFName, &ii, sizeof(ii));

          if (code == PVC_OK) {
            char num[10];

            memset(&sii, 0, sizeof(sii));
            sii.cbSize = sizeof(sii);
            sii.Format = outFmt;
            sii.Compression = outCompr;
            sii.Colors = outColors;
            if (Button_GetCheck(GetDlgItem(HWindow, IDC_GRAYS))) {
              sii.ColorModel = PVCM_GRAYS;
            }
            if (Button_GetCheck(GetDlgItem(HWindow, IDC_UNIFORM))) {
              sii.Flags |= PVSF_UNIFORM_PALETTE;
            }
            /* Determine target width and height; both must be non-zero to take effect */
            Edit_GetText(GetDlgItem(HWindow, IDC_WIDTH), num, sizeof(num));
            sii.Width = atoi(num);
            Edit_GetText(GetDlgItem(HWindow, IDC_HEIGHT), num, sizeof(num));
            sii.Height = atoi(num);

            if (Button_GetCheck(GetDlgItem(HWindow, IDC_FLIP_VERT))) {
              sii.Flags |= PVSF_FLIP_VERT;
            }
            if (Button_GetCheck(GetDlgItem(HWindow, IDC_FLIP_HOR))) {
              sii.Flags |= PVSF_FLIP_HOR;
            }
            if (Button_GetCheck(GetDlgItem(HWindow, IDC_INTERLACE))) {
              sii.Flags |= PVSF_INTERLACE;
            }
            if (Button_GetCheck(GetDlgItem(HWindow, IDC_APPEND))) {
              sii.Flags |= PVSF_APPEND_PAGE;
            }
            if (Button_GetCheck(GetDlgItem(HWindow, IDC_ROT90))) {
              sii.Flags |= PVSF_ROTATE90;
            }
            if (Button_GetCheck(GetDlgItem(HWindow, IDC_ROT180))) {
              sii.Flags ^= PVSF_FLIP_VERT | PVSF_FLIP_HOR;
            }
            if (Button_GetCheck(GetDlgItem(HWindow, IDC_ROT270))) {
              /* 270 is composition of 270 & 90 deg rotations */
              sii.Flags |= PVSF_ROTATE90;
              sii.Flags ^= PVSF_FLIP_VERT | PVSF_FLIP_HOR;
            }

            sii.CommentSize = Edit_GetTextLength(GetDlgItem(HWindow, IDC_COMMENT));
            if (sii.CommentSize > 0) {
              sii.CommentSize++; /* Include the terminating zero */
              sii.Comment = (char*)malloc(sii.CommentSize);
              Edit_GetText(GetDlgItem(HWindow, IDC_COMMENT), sii.Comment, sii.CommentSize);
            }
            /* Which page to read from the input? */
            Edit_GetText(GetDlgItem(HWindow, IDC_PAGE), num, sizeof(num));

            if ((outFmt == PVF_TIFF) && !IsDlgButtonChecked(HWindow, IDC_STRIPS)) {
               /* Saving to TIFF: Make a single strip */
               sii.Flags |= PVSF_DO_NOT_STRIP;
            }

            if (outFmt == PVF_JPG) {
               /* Saving to JPEG: set compression quality */
               sii.Misc.JPEG.Quality = GetDlgItemInt(HWindow, IDC_QUALITY, NULL, FALSE);
            }

            code = PVSaveImage(PVHandle, outputFName, &sii, NULL, NULL, atoi(num)-1);

            if (sii.CommentSize > 0) {
              /* We are responsible for freeing memory for comment */
              free(sii.Comment);
            }

            if (code != PVC_OK) {
              MessageBox(HWindow, PVGetErrorText(code), "Error converting file", MB_ICONEXCLAMATION);
            } else {
              MessageBox(HWindow, "Conversion succeeded", "Converting file", MB_OK);
            }
            PVCloseImage(PVHandle);
          } else {
            MessageBox(HWindow, PVGetErrorText(code), "Error opening input file", MB_ICONEXCLAMATION);
          }

          return TRUE;
        }
        case IDCANCEL:
        {
          EndDialog(HWindow, 0);
          return TRUE;
        }
      }
      break;
    }
  }
  return FALSE;    // not processed
}


int PASCAL WinMain (HINSTANCE hInstance, HINSTANCE hPrevInstance,
                    LPSTR lpszCmdLine, int nCmdShow)
{
  return DialogBoxParam(hInstance, MAKEINTRESOURCE(100), NULL, (DLGPROC)SaveDlgProc, (DWORD)lpszCmdLine);
}
