/*
 * DlgSamp.c - Shows an image in a dialog. Exhibits 2 techniques of creating DIB/DDB
 * ~~~~~~~~~   handle from raw image data.
 *
 * NOTE: must be linked with DlgSamp.rc and PVW32.lib
 *
 * Author: Jan Patera, 2003-2009
 */

#include <windows.h>
#include <windowsx.h>
#include "PVW32dll.h"
#include "DlgSamp.rh"


#if 0
/* Variant 1 */
HBITMAP  PVHandle2DIB(HWND hWnd, LPPVHandle PVHandle, LPPVImageInfo pvii)
{
  BITMAPINFO   bi;
  HBITMAP      hBmp, hOldBmp;
  HDC          hDC, hDC2;
  
  memset(&bi, 0, sizeof(bi));
  bi.bmiHeader.biSize = sizeof(bi.bmiHeader);
  bi.bmiHeader.biWidth = pvii->Width;
  bi.bmiHeader.biHeight = pvii->Height;
  bi.bmiHeader.biPlanes = 1;
  bi.bmiHeader.biBitCount = 24;
  hDC = GetDC(hWnd);
  hBmp = CreateDIBSection(hDC, &bi, DIB_RGB_COLORS, NULL, NULL, 0);
  hDC2 = CreateCompatibleDC(hDC);
  hOldBmp = SelectObject(hDC2, hBmp);
  PVDrawImage(PVHandle, hDC2, 0, 0, NULL);
  SelectObject(hDC2, hOldBmp);
  DeleteDC(hDC2);
  ReleaseDC(hWnd, hDC);
  return hBmp;
}

#else
/* Variant 2 */
HBITMAP  PVHandle2DIB(HWND hWnd, LPPVHandle PVHandle, LPPVImageInfo pvii)
{
  struct {
    BITMAPINFO   bi;
    RGBQUAD      pal[255];
  } bh;
  HBITMAP      hBmp;
  LPPVImageHandles pHandles;
  int          ccode, bpl;
  LPVOID       pData;
  
  ccode = PVGetHandles2(PVHandle, &pHandles);
  if (PVC_OK != ccode) {
     MessageBox(hWnd, PVGetErrorText(ccode), "Error getting image raw data", 0);
     return NULL;
  }
  memset(&bh, 0, sizeof(bh));
  bh.bi.bmiHeader.biSize = sizeof(bh.bi.bmiHeader);
  bh.bi.bmiHeader.biWidth = pvii->Width;
  bh.bi.bmiHeader.biHeight = pvii->Height;
  bh.bi.bmiHeader.biPlanes = 1;
  switch (pvii->Colors) {
     case PV_COLOR_HC15:
       bh.bi.bmiHeader.biBitCount = 16;
       bh.bi.bmiHeader.biCompression = BI_BITFIELDS;
       *(DWORD*)bh.bi.bmiColors = 0x7c00;
       *(DWORD*)&bh.pal[0] = 0x3e0;
       *(DWORD*)&bh.pal[1] = 0x1f;
       bpl = bh.bi.bmiHeader.biWidth * 2;
       break;
     case PV_COLOR_HC16:
       bh.bi.bmiHeader.biBitCount = 16;
       bh.bi.bmiHeader.biCompression = BI_BITFIELDS;
       *(DWORD*)bh.bi.bmiColors = 0xf800;
       *(DWORD*)&bh.pal[0] = 0x7e0;
       *(DWORD*)&bh.pal[1] = 0x1f;
       bpl = bh.bi.bmiHeader.biWidth * 2;
       break;
     case PV_COLOR_TC24:
     case PV_COLOR_TC32:  // 32-bit images are stored as 24-bit
       bh.bi.bmiHeader.biBitCount = 24;
       bpl = bh.bi.bmiHeader.biWidth * 3;
       break;
     case 2:
       bh.bi.bmiHeader.biBitCount = 1;
       bpl = (bh.bi.bmiHeader.biWidth + 7) >> 3;
       break;
     default:
       if (pvii->Colors <= 16) {
          bh.bi.bmiHeader.biBitCount = 4;
          bpl = (bh.bi.bmiHeader.biWidth + 1) >> 1;
       } else {
          bh.bi.bmiHeader.biBitCount = 8;
          bpl = bh.bi.bmiHeader.biWidth;
       }
  }
  if (pvii->Colors <= 256) {
     memcpy(&bh.bi.bmiColors, pHandles->Palette, pvii->Colors*4);
  }
  hBmp = CreateDIBSection(NULL, &bh.bi, DIB_RGB_COLORS, &pData, NULL, 0);
  if (hBmp && pData) {
     int    alignedBPL = (bpl+3) & ~3;
     DWORD  i;

     for (i = 0; i < pvii->Height; i++) {
        memcpy((char*)pData + (pvii->Height - i - 1)*alignedBPL, pHandles->pLines[i], bpl);
     }
  }
  return hBmp;
}
#endif

BOOL CALLBACK BitmapDlgProc(HWND HWindow, UINT uMsg, WPARAM wParam, LPARAM lParam)
{
  static  LPPVHandle      PVHandle = NULL;

  switch (uMsg)
  {
    case WM_INITDIALOG:
    {
      int          ccode;
      PVImageInfo  pvii;

      ccode = PVOpenImage(&PVHandle, (char*)lParam, &pvii, sizeof(pvii));
      if (PVC_OK != ccode)
      {
         MessageBox(HWindow, PVGetErrorText(ccode), "Error opening image file", 0);
         EndDialog(HWindow, 0);
         break;
      }
      ccode = PVReadImage2(PVHandle, 0, NULL, NULL, NULL, 0);
      if (PVC_OK != ccode)
      {
         MessageBox(HWindow, PVGetErrorText(ccode), "Error reading image", 0);
         EndDialog(HWindow, 0);
         break;
      }
      SendDlgItemMessage(HWindow, ID_IMAGE, STM_SETIMAGE, IMAGE_BITMAP, (LPARAM)PVHandle2DIB(HWindow, PVHandle, &pvii));
      break;
    }

    case WM_DESTROY:
      PVCloseImage(PVHandle);
      break;

    case WM_COMMAND:
    {
      switch (LOWORD(wParam))
      {
        case IDOK:
        case IDCANCEL:
        {
          EndDialog(HWindow, LOWORD(wParam));
          return TRUE;
        }
      }
      break;
    }
  }
  return FALSE;    // not processed
}


int PASCAL WinMain (HINSTANCE hInstance, HINSTANCE hPrevInstance,
                    LPSTR lpszCmdLine, int nCmdShow)
{
  if (!lpszCmdLine || !*lpszCmdLine)
  {
     MessageBox(0, "Usage:\n   DlgSamp.exe Image_File\n", "PictView32 DLL Demo", 0);
     return 0;
  }
  return DialogBoxParam(hInstance, MAKEINTRESOURCE(100), NULL, (DLGPROC)BitmapDlgProc, (DWORD)lpszCmdLine);
}
