/*
 * DumpImg.cpp - Demonstrates basic usage of PVW32.DLL.
 * ~~~~~~~~~~~   It prints information about all images present in the file
 *               specified on the command-line.
 *
 * NOTE:         Must be linked with PVW32.lib or PVW32Cnv.lib as
 *               a console application.
 *
 * Author: Jan Patera, 1999-2009
 */

#include <windows.h>
#include <stdio.h>
#include "PVW32DLL.h"

void PrintBinaryText(unsigned char *text, int len)
{
  while (len-- > 0){
    if (*text >= 32) {
      printf("%c", *text);
    } else {
      switch (*text) {
        case '\r' : printf("\\r"); break;
        case '\n' : printf("\\n"); break;
        case '\t' : printf("\\t"); break;
        case '\0' : printf("\\0"); break;
        default: printf("%#02x", *text);
      }
    }
    text++;
  }
}

int main(int argc, char *argv[])
{
  PVCODE       code;
  PVImageInfo  pvii;
  LPPVHandle   PVHandle;

  if (argc != 2)
   {
     printf("Image properties dumper\n\n");
     printf("Usage:\n  DumpImg.exe ImageFile\n");
     return 0;
   }

  code=PVOpenImage(&PVHandle, argv[1], &pvii, sizeof(pvii));
  if (code != PVC_OK)
   {
     puts(PVGetErrorText(code));
     return 1;
   }
  printf("Format: %i, NumOfImages: %i\n\n", pvii.Format, pvii.NumOfImages);
  for (DWORD i=0; i<pvii.NumOfImages; i++)
   {
     code=PVGetImageInfo(PVHandle, &pvii, sizeof(pvii), i);
     if (code != PVC_OK)
      printf("%s\n", PVGetErrorText(code));
     else
     {
        char dpi[20];
        if (pvii.HorDPI)
          sprintf(dpi, ", DPI: %dx%d", pvii.HorDPI, pvii.VerDPI);
        else
          dpi[0]=0;
        printf("%ix%i, %i colors: %s, %s, %s, %s%s\n", pvii.Width, pvii.Height,
          pvii.Colors, pvii.Info1, pvii.Info2, pvii.Info3,
          PVGetErrorText(pvii.Compression), dpi);
        if (pvii.CommentSize > 0) {
          /* There is a comment present */
          printf(" Comment (%d bytes): '", pvii.CommentSize);
          PrintBinaryText((unsigned char*)pvii.Comment, pvii.CommentSize);
          printf("'\n");
        }
     }

     if (pvii.FSI)
     {
        if (pvii.Format == PVF_TIFF) {
           // It is a GeoTIFF
           
           if (pvii.FSI->GeoTIFF.Flags & PVFS_GEOTIFF_TRM) {
              // Model Transformation Matrix
              puts("Model Transformation Matrix:");
              for (int j=0; j<16; j++) {
                 printf("%18.8f%c", pvii.FSI->GeoTIFF.TRM[j], (j%4 == 3) ? '\n' : ' ');
              }
           }
           if (pvii.FSI->GeoTIFF.Flags & PVFS_GEOTIFF_PIXELSIZE) {
              // Model Transformation Matrix
              puts("Pixel Scale:");
              for (int j=0; j<3; j++) {
                 printf("%18.8f%c", pvii.FSI->GeoTIFF.PixelSize[j], (j == 2) ? '\n' : ' ');
              }
           }
           if (pvii.FSI->GeoTIFF.Flags & PVFS_GEOTIFF_TIEPOINT) {
              // Tiepoint
              printf("Tipeoint (originally %d tiepoint%s\n", pvii.FSI->GeoTIFF.TiePointCount/6, pvii.FSI->GeoTIFF.TiePointCount ? ")": "s)");
              for (int j=0; j<6; j++) {
                 printf("%18.8f%c", pvii.FSI->GeoTIFF.TiePoint[j], (j%3 == 2) ? '\n' : ' ');
              }
           }
        } else {
           // Some general format-specific data
           char hex[]="0123456789abcdef";

           for (DWORD j=0; j<pvii.FSI->cbSize; j++) {
              printf("  %c%c", hex[(((char*)pvii.FSI)[j] & 0xF0)>>4], hex[((char*)pvii.FSI)[j] & 0xF]);
           }
        }
       printf("\n");
     }
   }
  PVCloseImage(PVHandle);
  return 0;
}