/*
 * Layers.c - Demonstrates the use of PVSetBWColors() function in PVW32.DLL.
 * ~~~~~~~~   This example reads a single monochrome image and displays
 *            it three times with a different color and transparent background.
 *
 * Author: Jan Patera, 2000-2009
 */

#include <windows.h>
#include "PVW32DLL.h"

#define XLine 10
#define YLine 10
#define XPage 100
#define YPage 100

char        szFrameClass [] = "PVW32Demo";
int         loaded=FALSE;
LPPVHandle  PVHandle;
PVImageInfo pvii;

/* This callback function displays the decompression progress
 */
BOOL WINAPI ProgressProcedure(int progress, void *hWnd)
{
  char s[64];

  wsprintf(s, "PVW32.DLL Layers Demo (%i%%)", progress);
  SetWindowText((HWND)hWnd, s);
  return FALSE;
}

void ScrollTo(HWND hWnd, int x, int y)
{
  int maxx, maxy, tmp;
  
  GetScrollRange(hWnd, SB_HORZ, &tmp, &maxx);
  GetScrollRange(hWnd, SB_VERT, &tmp, &maxy);
  x=min(x, maxx);
  y=min(y, maxy);
  if (x != -1)
   SetScrollPos(hWnd, SB_HORZ, x, TRUE);
  if (y != -1)
   SetScrollPos(hWnd, SB_VERT, y, TRUE);
}


void VScroll(HWND hWnd, int ScrollRequest, int ThumbPos)
{
  int YPos    = GetScrollPos(hWnd, SB_VERT);
  int newYPos = YPos;

  switch (ScrollRequest)
   {
     case SB_LINEDOWN:  newYPos = YPos + YLine; break;
     case SB_LINEUP:    newYPos = YPos - YLine; break;
     case SB_PAGEDOWN:  newYPos = YPos + YPage; break;
     case SB_PAGEUP:    newYPos = YPos - YPage; break;
     case SB_THUMBPOSITION: newYPos = ThumbPos; break;
     case SB_THUMBTRACK: newYPos = ThumbPos; break;
     case SB_ENDSCROLL: return;
  }
  ScrollTo(hWnd, -1, newYPos);
  newYPos = GetScrollPos(hWnd, SB_VERT);
  ScrollWindowEx(hWnd, 0, YPos - newYPos, NULL, NULL, NULL, NULL, SW_ERASE | SW_INVALIDATE);
}

void HScroll(HWND hWnd, int ScrollRequest, int ThumbPos)
{
  int XPos    = GetScrollPos(hWnd, SB_HORZ);
  int newXPos = XPos;

  switch (ScrollRequest)
   {
     case SB_LINERIGHT: newXPos = XPos + XLine; break;
     case SB_LINELEFT:  newXPos = XPos - XLine; break;
     case SB_PAGERIGHT: newXPos = XPos + XPage; break;
     case SB_PAGELEFT:  newXPos = XPos - XPage; break;
     case SB_THUMBPOSITION: newXPos = ThumbPos; break;
     case SB_THUMBTRACK: newXPos = ThumbPos; break;
     case SB_ENDSCROLL: return;
  }
  ScrollTo(hWnd, newXPos, -1);
  newXPos = GetScrollPos(hWnd, SB_HORZ);
  ScrollWindowEx(hWnd, XPos - newXPos, 0, NULL, NULL, NULL, NULL, SW_ERASE | SW_INVALIDATE);
}

/* The main window procedure
 */
LRESULT CALLBACK FrameWndProc(HWND hWnd, UINT message, WPARAM wParam,
     LPARAM lParam)
{
  PAINTSTRUCT  ps;
  HDC          hdc;
  unsigned     cw, ch, sw, sh, XRange, YRange;
  RECT         rect;

  switch (message)
  {
    case WM_PAINT:
            hdc=BeginPaint(hWnd, &ps);
            if (!loaded)
             {
               PVCODE   code;

               loaded = TRUE;
               code = PVReadImage2(PVHandle, NULL, NULL, ProgressProcedure, hWnd, 0);
               if (code != PVC_OK)
                {
                  MessageBox(hWnd, PVGetErrorText(code), "Error calling PVW32.DLL", MB_ICONEXCLAMATION);
                  if (code != PVC_CANCELED)
                    PostMessage(hWnd, WM_CLOSE, 0, 0);
                }
             }
            if (loaded)
             { /* We now display the image shifted 3 times with 3 colors */
               PVSetBWColors(PVHandle, 0xFF0000, PV_TRANSPARENT_COLOR);
               SetViewportOrgEx(hdc, -GetScrollPos(hWnd, SB_HORZ),
                -GetScrollPos(hWnd, SB_VERT), NULL);
               rect = ps.rcPaint;
               OffsetRect(&rect, GetScrollPos(hWnd, SB_HORZ), GetScrollPos(hWnd, SB_VERT));
               PVDrawImage(PVHandle, hdc, 0, 0, &rect);
               PVSetBWColors(PVHandle, 0xFF00, PV_TRANSPARENT_COLOR);
               SetViewportOrgEx(hdc, -GetScrollPos(hWnd, SB_HORZ)+10,
                -GetScrollPos(hWnd, SB_VERT)+10, NULL);
               OffsetRect(&rect, -10, -10);
               PVDrawImage(PVHandle, hdc, 0, 0, &rect);
               PVSetBWColors(PVHandle, 0xFF, PV_TRANSPARENT_COLOR);
               SetViewportOrgEx(hdc, -GetScrollPos(hWnd, SB_HORZ)+20,
                -GetScrollPos(hWnd, SB_VERT)+20, NULL);
               OffsetRect(&rect, -10, -10);
               PVDrawImage(PVHandle, hdc, 0, 0, &rect);
             }
            EndPaint(hWnd, &ps);
            return 0;
    case WM_SIZE:
            GetWindowRect(hWnd, &rect);
            cw=rect.right-rect.left-2*GetSystemMetrics(SM_CXFRAME);
            ch=rect.bottom-rect.top-2*GetSystemMetrics(SM_CYFRAME)-GetSystemMetrics(SM_CYCAPTION);
            sw=GetSystemMetrics(SM_CXVSCROLL); sh=GetSystemMetrics(SM_CYHSCROLL);
            XRange=YRange=0;
            if (pvii.Width+sw <= cw)  /* no horizontal scrollbar */
             {
               if (pvii.Height > ch)
                YRange=pvii.Height-ch;
             }
            else
             if (pvii.Width > cw)     /* yes horizontal scrollbar */
              {
                if (pvii.Height > ch-sh)
                 YRange=pvii.Height-ch+sh;
                else
                 sw=0;
                XRange=pvii.Width-cw+sw;
              }
             else                     /* maybe horizontal scrollbar */
              if (pvii.Height > ch)   /* yes vertical and therefore yes horizontal */
               {
                 XRange=pvii.Width-cw+sw;
                 YRange=pvii.Height-ch+sh;
               }
            SetScrollRange(hWnd, SB_HORZ, 0, XRange, TRUE/*redraw*/);
            SetScrollRange(hWnd, SB_VERT, 0, YRange, TRUE/*redraw*/);
            ShowScrollBar(hWnd, SB_HORZ, XRange ? TRUE : FALSE);
            ShowScrollBar(hWnd, SB_VERT, YRange ? TRUE : FALSE);
            break;
    case WM_VSCROLL:
            VScroll(hWnd, LOWORD(wParam), HIWORD(wParam));
            break;
    case WM_HSCROLL:
            HScroll(hWnd, LOWORD(wParam), HIWORD(wParam));
            break;

    case WM_QUERYENDSESSION:
    case WM_CLOSE:
            break;

    case WM_DESTROY:
            PostQuitMessage (0);
            return 0;
  }

  return DefWindowProc(hWnd, message, wParam, lParam);
}

int PASCAL WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance,
                    LPSTR lpszCmdLine, int nCmdShow)
{
  MSG      msg;
  WNDCLASS wndclass;
  PVCODE   code;
  HWND     hWnd;

  wndclass.style         = 0;
  wndclass.lpfnWndProc   = FrameWndProc;
  wndclass.cbClsExtra    = 0;
  wndclass.cbWndExtra    = 0;
  wndclass.hInstance     = hInstance;
  wndclass.hIcon         = 0;
  wndclass.hCursor       = LoadCursor (NULL, IDC_ARROW);
  wndclass.hbrBackground = GetStockObject (WHITE_BRUSH);
  wndclass.lpszMenuName  = NULL;
  wndclass.lpszClassName = szFrameClass;

  RegisterClass (&wndclass) ;

  if (!lpszCmdLine || !*lpszCmdLine)
    return MessageBox(0, "Usage: Layers.exe black_and_white_image_file", "PVW32.DLL Layers Demo", 0);

  pvii.Width=pvii.Height=CW_USEDEFAULT;

  code=PVOpenImage(&PVHandle, lpszCmdLine, &pvii, sizeof(pvii));
  if (PVC_OK != code)
   {
     MessageBox(0, PVGetErrorText(code), "Error calling PVW32.DLL", MB_ICONEXCLAMATION);
     return 0;
   }

  PVSetBkHandle(PVHandle, (HBRUSH)(COLOR_WINDOW+1));
  
  hWnd = CreateWindow(szFrameClass, "PVW32.DLL Layers Demo",
    WS_OVERLAPPEDWINDOW | WS_VSCROLL | WS_HSCROLL,
    CW_USEDEFAULT, CW_USEDEFAULT,
    pvii.Width+2*GetSystemMetrics(SM_CXFRAME),
    pvii.Height+2*GetSystemMetrics(SM_CYFRAME)+GetSystemMetrics(SM_CYCAPTION),
    NULL, NULL, hInstance, NULL);

  ShowWindow(hWnd, SW_SHOWNORMAL);
  ShowScrollBar(hWnd, SB_BOTH, FALSE);
  UpdateWindow(hWnd);

  while (GetMessage(&msg, NULL, 0, 0))
  {
    TranslateMessage(&msg);
    DispatchMessage(&msg);
  }
  PVCloseImage(PVHandle);
  return msg.wParam;
}

