(*
 * PasDemo1.pas - Demonstrates the basic usage of PVW32.DLL.
 * ~~~~~~~~~~~~   It simply loads and displays an image using a scrollable window.
 *
 * Author: Jan Patera, 1999-2009
 *)

unit PasDemo1;
interface

uses
  Windows, Forms, PVW32DLL;

type
  TDemo1 = class(TForm)
    procedure FormPaint(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormResize(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
  private
    pvii: TPVImageInfo;
    PVHandle: PPVHandle;
    Loaded: Boolean;
    { Private declarations }
  public
    { Public declarations }
  end;

var
  Demo1: TDemo1;

implementation

{$R *.DFM}

procedure TDemo1.FormPaint(Sender: TObject);
 var   code: TPVCODE;
begin
 if PVHandle<>0 then
  if not Loaded then
   begin
    { We read the image on first paint to display it as fast as possible. }
    Loaded:=True;
    code:=PVReadImage2(PVHandle, Canvas.Handle, NIL, NIL, NIL, 0);
    if code <> PVC_OK then
     MessageBox(Handle, PVGetErrorText(code), 'Error calling PVW32.dll', 0);
   end
  else
   PVDrawImage(PVHandle, Canvas.Handle, -HorzScrollBar.Position, -VertScrollBar.Position, NIL);
end;

procedure TDemo1.FormCreate(Sender: TObject);
 var   code: TPVCODE;
begin
 Loaded:=False; PVHandle:=0;
 if ParamCount > 0 then
  begin
   { An image is specified on the command-line. We check whether it exists and
     we can read it. }
   code:= PVOpenImage(PVHandle, PChar(ParamStr(1)), @pvii, SizeOf(pvii));
   if code <> PVC_OK then
    MessageBox(Handle, PVGetErrorText(code), 'Error opening image', 0)
   else
    begin
     { It seems we support this image so we adjust some window parameters. }
     if pvii.Width < ClientWidth then ClientWidth:=pvii.Width;
     if pvii.Height < ClientHeight then ClientHeight:=pvii.Height;
     Caption:=ParamStr(1)
    end;
  end
 else
  begin
   MessageBox(Handle, 'Usage: PasDemo1.exe image_file', 'PVW32.dll Demo 1', 0);
   Halt
  end;
end;

procedure TDemo1.FormResize(Sender: TObject);
begin
 if PVHandle<>0 then
  begin
   { On window resize we adjust scrollbar parameters. }
   HorzScrollBar.Visible:=True;
   HorzScrollBar.Range:=pvii.Width;
   VertScrollBar.Range:=pvii.Height;
  end;
end;

procedure TDemo1.FormClose(Sender: TObject; var Action: TCloseAction);
begin
 if PVHandle<>0 then
  begin
   PVCloseImage(PVHandle);
   PVHandle:=0
  end;
end;

end.
