(*
 * PasDemo2.pas - Demonstrates the basic usage of PVW32.DLL.
 * ~~~~~~~~~~~~   It simply loads and displays an image. The image gets
 *                automatically resized to the current window size using
 *                PVSetStretchParameters.
 * Author: Jan Patera, 1999-2009
 *)

unit PasDemo2;
interface

uses
  Windows, Forms, PVW32DLL;

type
  TDemo2 = class(TForm)
    procedure FormPaint(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormResize(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
  private
    pvii: TPVImageInfo;
    PVHandle: PPVHandle;
    Loaded: Boolean;
    { Private declarations }
  public
    { Public declarations }
  end;

var
  Demo2: TDemo2;

implementation

{$R *.DFM}

procedure TDemo2.FormPaint(Sender: TObject);
 var   code: TPVCODE;
begin
 if PVHandle<>0 then
  if not Loaded then
   begin
    { We read the image on first paint to display it as fast as possible. }
    Loaded:=True;
    code:=PVReadImage2(PVHandle, Canvas.Handle, NIL, NIL, NIL, 0);
    if code <> PVC_OK then
     MessageBox(Handle, PVGetErrorText(code), 'Error calling PVW32.dll', 0);
   end
  else
   PVDrawImage(PVHandle, Canvas.Handle, 0, 0, NIL);
end;

procedure TDemo2.FormCreate(Sender: TObject);
 var   code: TPVCODE;
begin
 Loaded:=False; PVHandle:=0;
 if ParamCount > 0 then
  begin
   { An image is specified on the command-line. We check whether it exists and
     we can read it. }
   code:= PVOpenImage(PVHandle, PChar(ParamStr(1)), @pvii, SizeOf(pvii));
   if code <> PVC_OK then
    MessageBox(Handle, PVGetErrorText(code), 'Error opening image', 0)
   else
    begin
     { It seems we support this image so we adjust some window parameters. }
     if pvii.Width < ClientWidth then ClientWidth:=pvii.Width;
     if pvii.Height < ClientHeight then ClientHeight:=pvii.Height;
     Caption:=ParamStr(1)
    end;
  end
 else
  begin
   MessageBox(Handle, 'Usage: PasDemo2.exe image_file', 'PVW32.DLL Demo 2', 0);
   Halt
  end;
end;

procedure TDemo2.FormResize(Sender: TObject);
begin
 if PVHandle<>0 then
  begin
   { On window resize we adjust image resizing. }
   PVSetStretchParameters(PVHandle, ClientWidth, ClientHeight, COLORONCOLOR);
   InvalidateRect(Handle, NIL, TRUE);
  end;
end;

procedure TDemo2.FormClose(Sender: TObject; var Action: TCloseAction);
begin
 if PVHandle<>0 then
  begin
   PVCloseImage(PVHandle);
   PVHandle:=0
  end;
end;

end.
