(*
 * TBitmp.dpr - Demonstrates basic usage of PVW32Cnv.DLL.
 * ~~~~~~~~~~   A combination of two examples with TBitmap:
 *              Loads an image into TBitmap and then saves it back to a GIF.
 *              NOTE: This is not the preferred way of converting files.
 *              For doing so, see the ToGIF example.
 *
 * NOTE:        Must be linked with PVW32Cnv.pas as a console application.
 *
 * Author: Jan Patera, 2006-2009
 *)

{$APPTYPE CONSOLE}
program TBitmap;
uses Graphics, Windows, SysUtils, Classes, pvw32cnv;

var
  sii:  TPVSaveImageInfo;
  hPVImage: PPVHandle;
  pvii: TPVImageInfo;
  pvoi: TPVOpenImageExInfo;
  code: TPVCODE;
  InpFileName, OutFileName: array[0..MAX_PATH] of char;
  bmp: Graphics.TBitmap;

{Main program}
begin
  if ParamCount <> 2 then
   begin
    WriteLn('Usage:');
    WriteLn(' TBitmap.exe  Image.ext   outFile.gif');
    Exit;
  end;
  { Create the output file }
  StrPCopy(InpFileName, ParamStr(1));
  StrPCopy(OutFileName, ParamStr(2));
  code := PVOpenImage(hPVImage, InpFileName, @pvii, sizeof(pvii));
  if code <> PVC_OK then
   begin
    WriteLn('Error ', code, ' opening file ', ParamStr(1), ':');
    WriteLn(PVGetErrorText(code));
    { Unknown file format? }
    Exit;
   end;
  bmp := Graphics.TBitmap.Create;
  bmp.Width := pvii.Width;
  bmp.Height := pvii.Height;
  code := PVReadImage2(hPVImage, bmp.Canvas.Handle, NIL, NIL, NIL, 0);
  PVCloseImage(hPVImage);

  pvoi.Size := sizeof(pvoi);
  pvoi.Flags  := PVOF_ATTACH_TO_HANDLE;
  pvoi.Handle := bmp.Handle;

  { Open the file }
  code := PVOpenImageEx(hPVImage, @pvoi, @pvii, sizeof(pvii));
  if code <> PVC_OK then
   begin
    WriteLn('Error ', code, ' opening file ', ParamStr(1), ':');
    WriteLn(PVGetErrorText(code));
    { Unknown file format? }
    Exit;
   end;
  code := PVReadImage2(hPVImage, 0, NIL, NIL, NIL, 0);

  FillChar(sii, sizeof(sii), 0);
  sii.Size := sizeof(sii);
  { PVF_BMP or any other format could be used as well }
  sii.Format := PVF_GIF;
  sii.Compression := PVCS_DEFAULT;
  sii.Colors := 256;
  sii.ColorModel := PVCM_RGB;

  code := PVSaveImage(hPVImage, OutFileName, sii, NIL, NIL, pvii.CurrentImage);

  if code <> PVC_OK then
   begin
    WriteLn('Error ', code, ' saving file ', ParamStr(2), ':');
    WriteLn(PVGetErrorText(code));
   end;

  { Close the input image }
  PVCloseImage(hPVImage);
  bmp.Free;
end.

