(*
 * ToGif.dpr - Demonstrates basic usage of PVW32Cnv.DLL.
 * ~~~~~~~~    Converts any image to GIF.
 *
 * NOTE:       Must be linked with PVW32Cnv.pas as a console application.
 *
 * Author: Jan Patera, 2009
 *)

{$APPTYPE CONSOLE}
program TBitmap;
uses SysUtils, pvw32cnv;

var
  sii:  TPVSaveImageInfo;
  hPVImage: PPVHandle;
  pvii: TPVImageInfo;
  code: TPVCODE;
  InpFileName, OutFileName: array[0..255] of char;

{Main program}
begin
  if ParamCount <> 2 then
   begin
    WriteLn('Usage:');
    WriteLn(' ToGif.exe  Image.ext   outFile.gif');
    Exit;
  end;
  { Create the output file }
  StrPCopy(InpFileName, ParamStr(1));
  StrPCopy(OutFileName, ParamStr(2));
  code := PVOpenImage(hPVImage, InpFileName, @pvii, sizeof(pvii));
  if code <> PVC_OK then
   begin
    WriteLn('Error ', code, ' opening file ', ParamStr(1), ':');
    WriteLn(PVGetErrorText(code));
    { Unknown file format? }
    Exit;
   end;

  FillChar(sii, 0, sizeof(sii));
  sii.Size := sizeof(sii);
  { PVF_BMP or any other format could be used as well }
  sii.Format := PVF_GIF;
  sii.Compression := PVCS_DEFAULT;
  if pvii.Colors > 256 then
   sii.Colors := 256
  else
   sii.Colors := pvii.Colors;
  sii.ColorModel := PVCM_RGB;

  if (pvii.Flags and PVFF_ROTATE90) <> 0 then
   begin
    sii.Flags := sii.Flags or PVSF_ROTATE90;
   end;
  if (pvii.Flags and PVFF_FLIP_HOR) <> 0 then
   begin
    sii.Flags := sii.Flags or PVSF_FLIP_HOR;
   end;

  code := PVSaveImage(hPVImage, OutFileName, sii, NIL, NIL, pvii.CurrentImage);

  if code <> PVC_OK then
   begin
    WriteLn('Error ', code, ' saving file ', ParamStr(2), ':');
    WriteLn(PVGetErrorText(code));
   end;

  { Close the input image }
  PVCloseImage(hPVImage);
end.

