(*****************************************************************************
 * PVW32Cnv.Pas - Delphi Interface to PVW32Cnv.DLL
 * 
 * Version 1.57
 *
 * Copyright (c) 1999-2010, Jan Patera
 *****************************************************************************)
unit PVW32Cnv;

interface
uses WinTypes;

const
  PV_MAX_INFO_LEN    = 30;
  PV_MAX_OUT_FORMATS = 21;

const
  PV_VERSION_100    =$10000;
  PV_VERSION_101    =$10001;
  PV_VERSION_102    =$10002;
  PV_VERSION_103    =$10003;
  PV_VERSION_104    =$10004;
  PV_VERSION_105    =$10005;
  PV_VERSION_106    =$10006;
  PV_VERSION_107    =$10007;
  PV_VERSION_108    =$10008;
  PV_VERSION_110    =$1000a;
  PV_VERSION_111    =$1000b;
  PV_VERSION_112    =$1000c;
  PV_VERSION_113    =$1000d;
  PV_VERSION_114    =$1000e;
  PV_VERSION_120    =$10014;
  PV_VERSION_121    =$10015;
  PV_VERSION_122    =$10016;
  PV_VERSION_150    =$10032;
  PV_VERSION_151    =$10033;
  PV_VERSION_152    =$10034;
  PV_VERSION_153    =$10035;
  PV_VERSION_154    =$10036;
  PV_VERSION_155    =$10037;
  PV_VERSION_156    =$10038;
  PV_VERSION_157    =$10039;

const { Color Bit-depths - used in TPVImageInfo.Colors }
  PV_COLOR_HC15     =65532;
  PV_COLOR_HC16     =65533;
  PV_COLOR_TC24     =65534;
  PV_COLOR_TC32     =65535;

const
  PV_MAXIMUM_BITMAP_SIZE  =$FFFFFFFF;

const { File formats - used in TPVImageInfo.Format }
  PVF_BMP	=1;
  PVF_PCX	=2;
  PVF_GIF	=3;
  PVF_TGA	=4;
  PVF_ICO	=5;
  PVF_CUT	=6;
  PVF_IMG	=7;
  PVF_TIFF	=8;
  PVF_RLE	=9;
  PVF_PSD	=10;
  PVF_RAS	=12;
  PVF_PCT	=13;
  PVF_LBM	=14;
  PVF_JPG	=15;
  PVF_MSP	=16;
  PVF_ICN	=17;
  PVF_JMX	=18;
  PVF_HRZ	=19;
  PVF_FLI	=20;
  PVF_PIC	=34;
  PVF_RIX	=35;
  PVF_CALS	=21;
  PVF_SGI	=22;
  PVF_PNG	=23;
  PVF_HSIJPG	=24;
  PVF_PC2	=25;
  PVF_MAC	=26;
  PVF_CUR	=27;
  PVF_CDR	=28;
  PVF_X		=29;
  PVF_Vivid	=30;
  PVF_PNM	=31;
  PVF_DCX	=32;
  PVF_WPG	=33;
  PVF_SAM	=36;
  PVF_CEL	=37;
  PVF_ZBR	=38;
  PVF_UDI	=39;
  PVF_CLP	=40;
  PVF_IRF	=41;
  PVF_OFX	=42;
  PVF_PCD	=43;
  PVF_PYX	=44;
  PVF_BMI	=45;
  PVF_ZMF	=46;
  PVF_AWD	=47;
  PVF_QFX	=48;
  PVF_XAR	=49;
  PVF_TI	=50;
  PVF_SKA	=51;
  PVF_RAW	=52;
  PVF_WBMP	=53;
  PVF_EPS	=54;
  PVF_MBM	=55;
  PVF_ZNO	=56;
  PVF_DTX	=57;
  PVF_DDS	=58;
  PVF_ANI	=59;
  PVF_CRW	=60;
  PVF_HPI	=61;
  PVF_Sapphire	=62;
  PVF_BLP	=63;

const { Image stretching  - used in PVSetStretchParameters }
  PV_STRETCH_NO        =0;   { do not stretch }

const { Transparent color for PVSetBWColors and PVSetTransparentColor }
  PV_TRANSPARENT_COLOR =COLORREF(-1);

const { Bit flags used in TPVImageInfo.Flags }
  PVFF_BOTTOMTOTOP      =1;   {Informational only}
  PVFF_SINGLEPASS       =2;
  PVFF_THUMBNAIL        =8;
  PVFF_THUMBNAILPRESENT =16;
  PVFF_FLIP_HOR         =32;  {Image needs horizontal flip for correct display}
  PVFF_FAST             =$1000;
  PVFF_ROTATE90         =$10000; {Image needs 90CW deg rotation (after mirror) for correct display}
  PVFF_EXIF             =$800000;
  PVFF_IPTC             =$1000000;

const { Color modes used in TPVImageInfo.ColorModel }
  PVCM_RGB             =0;
  PVCM_GRAYS           =1;
  PVCM_YIQ             =119; {Unsupported}
  PVCM_YCBCR           =120;
  PVCM_CMYK            =121;
  PVCM_UNKNOWN         =122; {Unsupported}
  PVCM_CIELAB          =257; {Unsupported}

const { Compression schemes used in TPVImageInfo.Compression }
      { Text strings can be extracted via PVGetErrorText }
  PVCS_DEFAULT         =0;   {Used for conversion only}
  PVCS_RLE             =19;  {Some variation of RunLength Encoding}
  PVCS_COMPRESSED      =39;  {Proprietary compression}
  PVCS_PACKBITS        =49;
  PVCS_NO_COMPRESSION  =57;  {Raw uncompressed data}
  PVCS_HUFFMAN         =58;
  PVCS_LZW             =59;
  PVCS_JPEG_LOSSLESS   =67;  {Loss-less JPEG, unsupported}
  PVCS_JPEG_HUFFMAN    =123; {Lossy JPEG}
  PVCS_JPEG_ARITH      =124; {Lossy JPEG, unsupported}
  PVCS_CCITT_3         =203;
  PVCS_CCITT_4         =204;
  PVCS_UNKNOWN         =205; {Unknown compression, unsupported}
  PVCS_CFA             =206; {Color Filter Array, used by digital cameras, unsupported}
  PVCS_DEFLATE         =236;
  PVCS_ASCII           =296; {ASCII PNM, supported for export only}

const { Flags for TPVSupFormat.Schemes }
  PVSOCS_NO_COMPRESSION = 1;
  PVSOCS_RLE            = 2;
  PVSOCS_PACKBITS       = 4;
  PVSOCS_HUFFMAN        = 8;
  PVSOCS_CCITT_3        = 16;
  PVSOCS_CCITT_4        = 32;
  PVSOCS_LZW            = 64;
  PVSOCS_JPEG           = 128;
  PVSOCS_JPEG_LOSSLESS  = 256;   {Not supported yet}
  PVSOCS_DEFLATE        = 512;
  PVSOCS_ASCII          = 1024;
  PVSOCS_INTERLACE      = 16384; {Not supported yet}
  PVSOCS_TILE           = 32768; {Not supported yet}

const { Flags for TPVSaveImageInfo.Flags }
  PVSF_UNIFORM_PALETTE  = $0020; {Create uniform 216-color palette for web}
  PVSF_INVERT           = $0040; {Invert bilevel image}
{  PVSF_TRANSPARENT      = $0080; Obsolete, please use PVSaveImageInfo.Transp}
  PVSF_FLIP_VERT        = $0100; {Flip image vertically}
  PVSF_FLIP_HOR         = $0200; {Flip image horizontally}
  PVSF_GIF89            = $0400; {Create GIF89a instead of GIF87a}
  PVSF_APPEND_PAGE      = $0800; {Append page to an existing file (output format must be multipage)}
  PVSF_DO_NOT_STRIP     = $1000; {Do not split TIFFs into strips}
  PVSF_PREDICT          = $2000; {Predict TIFFs compressed with LZW}
  PVSF_INTERLACE        = $4000; {Create interlaced GIF}
  PVSF_TILE             = $8000; {Not supported yet}
  PVSF_USERDEFINED_OUTPUT =$10000; {WriteFunc & SeekFunc shall be used}
  PVSF_ROTATE90         = $20000; {Rotate 90deg clockwise}

const { Transparency flags, used by PVSaveImageInfo.Transp.Flags }
  PVTF_NONE             = 0;  {No transparent color; default}
  PVTF_ORIGINAL         = 1;  {Preserve transparent color from original input file}
  PVTF_INDEX            = 2;  {Palette index specified in PVSaveImageInfo.Transp.Value.Index}
  PVTF_RGB              = 3;  {Color specified in PVSaveImageInfo.Transp.Value.RGB}

const { Flags for PVOpenImageExInfo.Flags }
  PVOF_ATTACH_TO_HANDLE = $0001; {Attach DDB or DIB handle}
  PVOF_USERDEFINED_INPUT= $0002; {Use user-defined Read and Seek functions}
  PVOF_THUMBNAIL        = $0004; {Look for a thumbnail}

const { Disposal methods for image sequences, used by PVImageSequence.Flags }
  PVDM_UNDEFINED        = 0;     { No disposal specified }
  PVDM_UNMODIFIED       = 1;     { Do not dispose. The graphic is to be left in place }
  PVDM_BACKGROUND       = 2;     { Restore to background color }
  PVDM_PREVIOUS         = 3;     { Restore to previous: what was there prior to rendering the graphic }

const { Flags for TPVFormatSpecificInfo.GeoTIFF.Flags }
 PVFS_GEOTIFF_TRM       = 1;
 PVFS_GEOTIFF_PIXELSIZE = 2;
 PVFS_GEOTIFF_TIEPOINT  = 4;

type
  DWORD         = LongInt;
  TPVCODE       = DWORD;
  TProgressProc = function(Done: Integer; AppSpecific: pointer): Boolean; stdcall;
  Real64        = array[0..7] of Byte;
  TRGBQuadArray = array[0..255] of TRGBQuad;
  PPVHandle     = THANDLE;
  TPVReadFunc   = function(AppSpecific: DWORD; var pData; Size: DWORD): DWORD; stdcall;
  TPVSeekFunc   = function(AppSpecific: DWORD; NewPos: DWORD; Origin: DWORD): DWORD; stdcall;
  TPVWriteFunc  = function(AppSpecific: DWORD; var pData; Size: DWORD): DWORD; stdcall;


type
  PPVImageHandles=^TPVImageHandles;
  TPVImageHandles=record
    TransparentHandle: THandle;
    TransparentBackgroundHandle: THandle;
    HPal: HPalette;
{ Added in version 1.02: }
    StretchedHandle: THandle;
{ Added in version 1.03: }
    StretchedTransparentHandle: THandle;
{ Added in version 1.08: }
    Palette: ^TRGBQuadArray;
{ Added in version 1.50: }
    Lines: ^PBYTE; { Array of pointers to image lines }
   end;


type
 PPVFormatSpecificInfo=^TPVFormatSpecificInfo;
 TPVFormatSpecificInfo=packed record
   Size:   DWORD;
   case Integer of
    0:(IRF:packed record
	   XOR1: Real64;  { X View Origin }
           YOR: Real64;   { Y View Origin }
           ZOR: Real64;   { Z View Origin }
           XDL: Real64;   { X View Extent }
           YDL: Real64;   { Y View Extent }
           ZDL: Real64;   { Z View Extent }
           TRN: array[0..15] of Real64; { Transformation Matrix }
           SLO: Byte;     { Scanline Orientation }
           Fill: array[0..2] of byte; {Padding to 32 bits} 
           ROT: Real64;   { Rotation Angle }
           SKW: Real64;   { Skew Angle }
	  end);
    1:(GIF:packed record
           ScreenWidth:  DWORD;
           ScreenHeight: DWORD;
	   XPosition:    DWORD;
           YPosition:    DWORD;
           Delay:        DWORD;
           TranspIndex:  DWORD;
           BgColor:      COLORREF; { Background color }
           DisposalMethod: DWORD;  { see PVDM_xxx flags }
          end);
    2:(GeoTIFF:packed record
           Flags: DWORD;  {PVFS_GEOTIFF_XXXX}
           TRM: array[0..15] of Real64;      { Transformation Matrix }
           PixelSize: array[0..2] of Real64; { ModelPixelScaleTag }
           TiePointCount: DWORD;             { Real number of tie point items in the file }
           TiePoint: array[0..5] of Real64;  { First 6 items of ModelTiepointTag }
          end);
    3:(ANI:packed record
           cbSize: DWORD;  { Num bytes in AniHeader (36 bytes) }
           cFrames: DWORD; { Number of unique Icons in this cursor }
           cSteps: DWORD;  { Number of Blits before the animation cycles }
           cx, cy: DWORD;  { reserved, must be zero. }
           cBitCount, cPlanes: DWORD; { reserved, must be zero. }
           JifRate: DWORD; { Default Jiffies (1/60th of a second) if rate chunk not present. }
           flags: DWORD;   { Animation Flag (see AF_ constants) }
          end);
  end;


 PPVImageInfo=^TPVImageInfo;
 TPVImageInfo=record
   Size: DWORD;
   Width, Height: DWORD;
   BytesPerLine: DWORD;
   FileSize: DWORD;
   Colors: DWORD;
   Format: DWORD;
   Flags: DWORD;
   ColorModel: DWORD;
   NumOfImages: DWORD;
   CurrentImage: DWORD;
   Info1, Info2, Info3: array[0..PV_MAX_INFO_LEN-1] of char;
{ Added in version 1.02: }
   StretchedWidth, StretchedHeight: DWORD;
   StretchMode: DWORD;
{ Added in version 1.03: }
   HorDPI: DWORD;
   VerDPI: DWORD;
   FSI: PPVFormatSpecificInfo;
{ Added in version 1.07: }
   Compression: DWORD;
{ Added in version 1.14: }
   CommentSize:	DWORD;
   Comment:	PChar;
{ Added in version 1.53: }
   TotalBitDepth: DWORD;
  end;

 PPVMemoryOptions2=^TPVMemoryOptions2;
 TPVMemoryOptions2=record
     Size: DWORD;
     MaxZoomedDDB:  DWORD;
    end;

type
 TPVSupFormat = record
   Format:    Word;
   Flags:     Word;
   Schemes:   array[0..9] of Word;
    {1, 4, 8, Grays, 15, 16, 24, 32 bits, CMYK, reserved}
   Extensions: PChar;
   Reserved:   pointer;
  end;

type
 PPVSupOutFormats=^TPVSupOutFormats;
 TPVSupOutFormats=record
   NumOfItems: DWORD;
   Formats: array[0..PV_MAX_OUT_FORMATS-1] of TPVSupFormat;
  end;

type
 PPVSaveImageInfo=^TPVSaveImageInfo;
 TPVSaveImageInfo=record
   Size:   DWORD;
   Format: DWORD;
   Compression: DWORD;
   Colors: DWORD;
   ColorModel: DWORD;
   Flags:  DWORD;
   Width:  DWORD;
   Height: DWORD;
   HorDPI: DWORD;
   VerDPI: DWORD;
   CommentsSize: DWORD;
   Comments: PChar;
   Misc: record
      case Integer of
       0:(GIF:  record
{                 TranspIndex: DWORD; Obsolete, please use PVSaveImageInfo.Transp}
                end);
       1:(TIFF: record
                 StripSize: DWORD;
                 JPEGQuality: DWORD;
                 JPEGSubSampling: DWORD;
                end);
       2:(JPEG: record
                 Quality: DWORD;
                 SubSampling: DWORD;
                end);
       3:(IRF:packed record
                 XOR1: Real64;  { X View Origin }
                 YOR: Real64;   { Y View Origin }
                 ZOR: Real64;   { Z View Origin }
                 XDL: Real64;   { X View Extent }
                 YDL: Real64;   { Y View Extent }
                 ZDL: Real64;   { Z View Extent }
                 TRN: array[0..15] of Real64; { Transformation Matrix }
                 SLO: Byte;     { Scanline Orientation }
                 Fill: array[0..2] of byte; {Padding to 32 bits; set to zero} 
                 ROT: Real64;   { Rotation Angle }
                 SKW: Real64;   { Skew Angle }
                end);
       127:(Reserved: array[0..255] of Byte);
      end;
   WriteFunc:	TPVWriteFunc;
   SeekFunc:	TPVSeekFunc;
{ Added in version 1.20: }
   ReadFunc: TPVReadFunc; { Needed for appending page to multipage file }
{ Added in version 1.52: }
   CropLeft:    DWORD;    { Cropping applied before scaling }
   CropTop:     DWORD;
   CropWidth:   DWORD;    { Crop size }
   CropHeight:  DWORD;    { No cropping applied if CropWidth or CropHeight is zero }
{ Added in version 1.56: }
   Transp: record
      Flags: BYTE;       { PVTF_XXX flags }
      Value: record
       case Integer of
        0: (Index: BYTE);  { Used only when Flags is PVTF_INDEX }
        1: (RGB: packed record
             Red, Green, Blue: BYTE; { Used only when Flags is PVTF_RGB }
             end);
      end;
    end;
  end;

type
 PPVOpenImageExInfo=^TPVOpenImageExInfo;
 TPVOpenImageExInfo=record
   Size:	DWORD;
   Flags:	DWORD;
   Handle:	THandle;
   ReadFunc:	TPVReadFunc;
   SeekFunc:	TPVSeekFunc;
   DataSize:	DWORD;
   FileName:	PChar;
  end;

const
  PVC_EXPIRED                    =-8;	{ Demo version has expired }
  PVC_GDI_ERROR                  =-7;   { GDI function like SelectObject failed }
  PVC_EXCEPTION                  =-6;   { Internal error. Damaged file? }
  PVC_CANCELED                   =-5;	{ Progress function returned non-zero }
  PVC_NO_MORE_IMAGES             =-4;	{ No more images in the file }
  PVC_OOM                        =-3;	{ Out of memory }
  PVC_SYNC_ERROR                 =-2;   { Synchronization error }
  PVC_INVALID_HANDLE             =-1;
  PVC_OK                         =0;
  PVC_UNKNOWN_COMPRESSION        =6;
  PVC_OUT_OF_MEMORY              =7;
  PVC_TOO_MANY_BITS_PER_PLANE    =9;
  PVC_LOSSLESS_JPEG_UNSUP        =17;
  PVC_TOO_MUCH_FRAGMENTED_FILE   =70;
  PVC_CMYK_UNSUP                 =74;
  PVC_YIQ_UNSUP                  =75;
  PVC_UNKNOWN_COLOR_MODEL        =76;
  PVC_ARITHMETIC_COMP_UNSUP      =77;
  PVC_UNEXPECTED_EOF             =78;
  PVC_UNEXPECTED_MARKER_IN_FILE  =79;
  PVC_UNEXPECTED_MARKER_IN_DATA  =80;
  PVC_TOO_MANY_HUFFMAN_TABLES    =81;
  PVC_TOO_MANY_COL_COMPONENTS    =82;
  PVC_NON_INTERLEAVING_UNSUP     =83;
  PVC_BAD_NUM_OF_COL_COMPONENTS  =84;
  PVC_BOGUS_DRI_MARKER_SIZE      =85;
  PVC_HEIGHT_UNKNOWN_PRIOR_DECOMP =86;
  PVC_UNKNOWN_MARKER_FOUND       =87;
  PVC_UNSUP_SUBSAMPLING          =88;
  PVC_TOO_MANY_QUANT_TABLES      =89;
  PVC_INVALID_DIMENSIONS         =91;
  PVC_UNSUP_FILE_TYPE            =94;
  PVC_COMPED_TC_IMAGES_UNSUP     =96;
  PVC_UNKNOWN_FILE_STRUCT        =97;
  PVC_CANNOT_OPEN_FILE           =99;
  PVC_NO_IMAGES_IN_AMIPRO_DOC    =100;
  PVC_NO_HUFFMAN_TABLE_DEFINED   =111;
  PVC_UNSUP_CONTROL_BYTE         =112;
  PVC_WRITING_ERROR              =115;
  PVC_READING_ERROR              =117;
  PVC_UNSUP_NUM_OF_COLORS        =126;
  PVC_UNSUP_DIMENSIONS           =130;
  PVC_NO_FILES_FOUND             =180;
  PVC_NOT_YET_SUP_COMP           =195;
  PVC_BAD_FILE_HEADER_SIZE       =207;
  PVC_OVERFLOW_OF_HUFFMAN_TABLE  =209;
  PVC_UNSUP_NUM_OF_COL_COMPONENTS =223;
  PVC_DIFFERENT_BPS_UNSUP        =224;
  PVC_UNSUP_TYPE_OF_INTERLEAVING =232;
  PVC_TOO_BIG_DECOMP_BUF         =243;
  PVC_INCORRECT_UNCOMP_BLOCK_SIZE =244;
  PVC_INTERLEAVING_LIMITED       =245;
  PVC_INCORRECT_HEADER_CRC       =246;
  PVC_HSI_JPEG_UNSUP             =248;
  PVC_UNKNOWN_FILTER             =250;
  PVC_2D_CCITT3_UNSUP            =253;
  PVC_UNCOMP_CCITT3_UNSUP        =254;
  PVC_BAD_SCAN_DEFINITION        =280;
  PVC_UNSUP_NUM_OF_COMPONENTS_IN_SCAN =281;
  PVC_ERROR_CREATING_FILE        =287;
  PVC_ASCII_FORMAT_UNSUP         =297;
  PVC_BOGUS_HUFFMAN_TABLE        =310;
  PVC_INCORRECT_PARAMETER        =312;
  PVC_PREVIEW_NOT_PRESENT        =313;
  PVC_UNSUP_COLOR_DEPTH          =319;
  PVC_TOO_WIDE_FOR_GIVEN_SUBSAMPLING =325;
  PVC_VECTOR_FILES_UNSUP         =326;
  PVC_AUDIO_FILES_UNSUP          =332;
  PVC_IMAGE_TOO_BIG              =344;
  PVC_IMAGE_TOO_WIDE             =345;
  PVC_UNSUP_OUT_PARAMS           =346;
  PVC_CANNOT_FIND_TRANSPARENT_COLOR = 347;


function PVCloseImage(Img: PPVHandle): TPVCODE; stdcall;
function PVCropImage(Img: PPVHandle; Left, Top, Width, Height: Integer): TPVCODE; stdcall;
function PVDrawImage(Img: PPVHandle; PaintDC: HDC; X, Y: Integer; DCRect: PRect): TPVCODE; stdcall;
function PVGetDLLVersion:DWORD; stdcall;
function PVGetErrorText(ErrorCode: DWORD): PChar; stdcall;
function PVGetHandles2(Img: PPVHandle; var Handles: PPVImageHandles): TPVCODE; stdcall;
function PVGetImageInfo(Img: PPVHandle; pImgInfo: pointer; Size: Integer; ImageIndex: Integer): TPVCODE; stdcall;
function PVGetLicenseString: PChar; stdcall;
function PVGetMemoryOptions2(pMemoryOptions: pointer; Size: Integer): TPVCODE; stdcall;
function PVGetSupOutFormats: PPVSupOutFormats; stdcall;
function PVIsOutCombSupported(Fmt: Integer; Compr: Integer; Colors: Integer; ColorModel: Integer): Integer; stdcall;
function PVLoadFromClipboard(var Img: PPVHandle; pImgInfo: pointer; Size: Integer): TPVCODE; stdcall;
function PVOpenImage(var Img: PPVHandle; FileName: PChar; pImgInfo: pointer; Size: Integer): TPVCODE; stdcall;
function PVOpenImageEx(var Img: PPVHandle; pOpenExInfo: PPVOpenImageExInfo; pImgInfo: pointer; Size: Integer): TPVCODE; stdcall;
function PVReadImage2(Img: PPVHandle; PaintDC: HDC; DRect: PRECT; Progress: TProgressProc; AppSpecific: pointer; ImageIndex: Integer): TPVCODE; stdcall;
function PVSaveImage(Img: PPVHandle; OutFName: PChar; var sii: TPVSaveImageInfo; Progress: TProgressProc; AppSpecific: pointer; ImageIndex: Integer):TPVCODE; stdcall;
function PVSetBkHandle(Img: PPVHandle; BkHandle: THandle): TPVCODE; stdcall;
function PVSetMaxDIBSize(Img: PPVHandle; Size: Cardinal): TPVCODE; stdcall;
function PVSetMemoryOptions2(var MemoryOptions: TPVMemoryOptions2): TPVCODE; stdcall;
function PVSetStretchParameters(Img: PPVHandle; Width, Height: DWORD; Mode: DWORD): TPVCODE; stdcall;
function PVSetTransparentColor(Img: PPVHandle; TranspColor: COLORREF): TPVCODE; stdcall;
function PVSetBWColors(Img: PPVHandle; Black: COLORREF; White: COLORREF): TPVCODE; stdcall;

implementation

 function PVCloseImage; external 'PVW32Cnv.DLL' index 1;
 function PVCropImage; external 'PVW32Cnv.DLL' index 55;
 function PVDrawImage;  external 'PVW32Cnv.DLL' index 2;
 function PVGetDLLVersion; external 'PVW32Cnv.DLL' index 3;
 function PVGetErrorText; external 'PVW32Cnv.DLL' index 4;
 function PVGetHandles2; external 'PVW32Cnv.DLL' index 18;
 function PVGetImageInfo; external 'PVW32Cnv.DLL' index 5;
 function PVGetLicenseString; external 'PVW32Cnv.DLL' index 11;
 function PVGetMemoryOptions2; external 'PVW32Cnv.DLL' index 20;
 function PVGetSupOutFormats; external 'PVW32Cnv.DLL' index 50;
 function PVIsOutCombSupported; external 'PVW32Cnv.DLL' index 53;
 function PVLoadFromClipboard; external 'PVW32Cnv.DLL' index 15;
 function PVOpenImage; external 'PVW32Cnv.DLL' index 6;
 function PVOpenImageEx; external 'PVW32Cnv.DLL' index 17;
 function PVReadImage2; external 'PVW32Cnv.DLL' index 19;
 function PVSaveImage; external 'PVW32Cnv.DLL' index 51;
 function PVSetBkHandle; external 'PVW32Cnv.DLL' index 8;
 function PVSetMaxDIBSize; external 'PVW32Cnv.DLL' index 9;
 function PVSetMemoryOptions2; external 'PVW32Cnv.DLL' index 21;
 function PVSetStretchParameters; external 'PVW32Cnv.DLL' index 12;
 function PVSetTransparentColor; external 'PVW32Cnv.DLL' index 22;
 function PVSetBWColors; external 'PVW32Cnv.DLL' index 16;

end.
